@@ -258,7 +258,7 @@ class FedMsgContext(object):
         **An example from Fedora Tagger -- SQLAlchemy encoding**
 
         Here's an example from
-        `fedora-tagger <http://github.com/ralphbean/fedora-tagger>`_ that
+        `fedora-tagger <http://github.com/fedora-infra/fedora-tagger>`_ that
         sends the information about a new tag over
         ``org.fedoraproject.{dev,stg,prod}.fedoratagger.tag.update``::
 
@@ -292,13 +292,8 @@ class FedMsgContext(object):
 
         """
 
-        if not topic:
-            warnings.warn("Attempted to send message with no topic.  Bailing.")
-            return
-
-        if not msg:
-            warnings.warn("Attempted to send message with no msg.  Bailing.")
-            return
+        topic = topic or 'unspecified'
+        msg = msg or dict()
 
         # If no modname is supplied, then guess it from the call stack.
         modname = modname or self.guess_calling_module(default="fedmsg")
